@@ -1,5 +1,6 @@
 /*  RTMP Dump
  *  Copyright (C) 2008-2009 Andrej Stepanchuk
+ *  Copyright (C) 2009 Howard Chu
  *
  *  This Program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,8 +24,11 @@
 
 #include <stdio.h>
 
-// Enable this to get full debugging output
-//#define _DEBUG
+#ifdef __cplusplus
+extern "C" {
+#endif
+/* Enable this to get full debugging output */
+/* #define _DEBUG */
 
 #ifdef _DEBUG
 #undef NODEBUG
@@ -35,12 +39,27 @@
 #define LOGWARNING	2
 #define LOGINFO		3
 #define LOGDEBUG	4
-#define LOGALL		5
+#define LOGDEBUG2	5
+#define LOGALL		6
+
+#define Log	AMF_Log
+#define LogHex	AMF_LogHex
+#define LogHexString	AMF_LogHexString
+#define LogPrintf	AMF_LogPrintf
+#define LogSetOutput	AMF_LogSetOutput
+#define LogStatus	AMF_LogStatus
+#define debuglevel	AMF_debuglevel
+
+extern int debuglevel;
 
 void LogSetOutput(FILE *file);
 void LogPrintf(const char *format, ...);
+void LogStatus(const char *format, ...);
 void Log(int level, const char *format, ...);
-void LogHex(const char *data, unsigned long len);
-void LogHexString(const char *data, unsigned long len);
+void LogHex(int level, const char *data, unsigned long len);
+void LogHexString(int level, const char *data, unsigned long len);
 
+#ifdef __cplusplus
+}
+#endif
 #endif
